package BorderStyles::Test;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-06-11'; # DATE
our $DIST = 'BorderStyles-Test'; # DIST
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: A collection of border styles, mainly for testing

__END__

=pod

=encoding UTF-8

=head1 NAME

BorderStyles::Test - A collection of border styles, mainly for testing

=head1 VERSION

This document describes version 0.002 of BorderStyles::Test (from Perl distribution BorderStyles-Test), released on 2020-06-11.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/BorderStyles-Test>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-BorderStyles-Test>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=BorderStyles-Test>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<BorderStyle> - specification

L<App::BorderStyleUtils> - CLIs

L<Text::Table::TinyBorderStyle>, L<Text::ANSITable> - some table renderers that can use border styles

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
